# NCUPhy

This project provides modules for controlling 

    Motor(s)
    -Stepper Motor
    
    ADC(s)
    -ADS1115
    
    Sensor(s)
    -MPU9250
    -MPU6050


## Installation

```sh
pip install ncuphy